@@ -3,7 +3,7 @@
 require "net/imap"
 require "test/unit"
 
-class IMAPSequenceSetTest < Test::Unit::TestCase
+class IMAPSequenceSetTest < Net::IMAP::TestCase
   # alias for convenience
   SequenceSet     = Net::IMAP::SequenceSet
   DataFormatError = Net::IMAP::DataFormatError
@@ -15,9 +15,13 @@ class IMAPSequenceSetTest < Test::Unit::TestCase
 
   if ENV["PROFILE_ALLOCATIONS"] =~ /\A(1|y(es)?|t(rue)?)\z/i
     module ProfileAllocations
-      def setup = @allocated = GC.stat(:total_allocated_objects)
+      def setup
+        @allocated = GC.stat(:total_allocated_objects)
+        super
+      end
 
       def teardown
+        super
         return unless @allocated
         allocated = GC.stat(:total_allocated_objects)
         $stderr.puts "Allocated: %6d in %p" % [allocated - @allocated, local_name]
@@ -293,6 +297,10 @@ class IMAPSequenceSetTest < Test::Unit::TestCase
     assert_nil SequenceSet.try_convert("12:34")
     assert_nil SequenceSet.try_convert(Object.new)
 
+    obj = Object.new
+    def obj.to_sequence_set; nil end
+    assert_nil SequenceSet.try_convert(obj)
+
     obj = Object.new
     def obj.to_sequence_set; SequenceSet[192, 168, 1, 255] end
     assert_equal SequenceSet[192, 168, 1, 255], SequenceSet.try_convert(obj)
